/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DLAY.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DLAY *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DLAY_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DLAY();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DLAY::Heavy_WSTD_DLAY(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_9srhMAgI);
  numBytes += sLine_init(&sLine_mLOdv0pY);
  numBytes += sTabhead_init(&sTabhead_jpXBdg5E, &hTable_SM7okjh9);
  numBytes += sTabread_init(&sTabread_L3Gk7I70, &hTable_SM7okjh9, false);
  numBytes += sTabread_init(&sTabread_Hut3FTCE, &hTable_SM7okjh9, false);
  numBytes += sLine_init(&sLine_lkuoKWSv);
  numBytes += sLine_init(&sLine_stIXvvmX);
  numBytes += sLine_init(&sLine_CC2ESNlM);
  numBytes += sTabhead_init(&sTabhead_rhGB4tdQ, &hTable_MQncEn8s);
  numBytes += sTabread_init(&sTabread_1ooqB4uT, &hTable_MQncEn8s, false);
  numBytes += sTabread_init(&sTabread_n5BCh1O1, &hTable_MQncEn8s, false);
  numBytes += sLine_init(&sLine_vCojiN78);
  numBytes += sTabwrite_init(&sTabwrite_T440nWX7, &hTable_SM7okjh9);
  numBytes += sTabwrite_init(&sTabwrite_oFijAhFP, &hTable_MQncEn8s);
  numBytes += sRPole_init(&sRPole_kui4inrM);
  numBytes += sRPole_init(&sRPole_AcTR6MJm);
  numBytes += sRPole_init(&sRPole_foSd1y6U);
  numBytes += sDel1_init(&sDel1_6RTjs918);
  numBytes += sLine_init(&sLine_iFit4FEA);
  numBytes += sLine_init(&sLine_jROL20tm);
  numBytes += sRPole_init(&sRPole_FnEjEyXf);
  numBytes += sRPole_init(&sRPole_qZ5Exg3F);
  numBytes += sRPole_init(&sRPole_rqpbwQeI);
  numBytes += sDel1_init(&sDel1_OOqeQ7E0);
  numBytes += sLine_init(&sLine_cPOTQ0zT);
  numBytes += sLine_init(&sLine_yf4r5mYK);
  numBytes += sLine_init(&sLine_EaRaYPbQ);
  numBytes += sLine_init(&sLine_Tedpgzmd);
  numBytes += cVar_init_f(&cVar_qkhe8zn6, 0.0f);
  numBytes += cVar_init_f(&cVar_79Xg04sH, 0.0f);
  numBytes += cVar_init_f(&cVar_stQnS0zA, 0.0f);
  numBytes += cVar_init_f(&cVar_DfLAReGG, 0.0f);
  numBytes += cSlice_init(&cSlice_DvJWmnQm, 1, -1);
  numBytes += cVar_init_f(&cVar_sJ9DkADi, 0.5f);
  numBytes += cSlice_init(&cSlice_3a5l4Tc7, 1, -1);
  numBytes += cVar_init_f(&cVar_5XFL79mp, 0.2f);
  numBytes += cSlice_init(&cSlice_mCEEP4EH, 1, -1);
  numBytes += cVar_init_f(&cVar_DxFEMHHU, 500.0f);
  numBytes += cSlice_init(&cSlice_BhrX4HHP, 1, -1);
  numBytes += cVar_init_f(&cVar_FoirY4B7, 0.25f);
  numBytes += cDelay_init(this, &cDelay_dheeunJH, 0.0f);
  numBytes += cDelay_init(this, &cDelay_gieYQh9T, 0.0f);
  numBytes += hTable_init(&hTable_SM7okjh9, 256);
  numBytes += cDelay_init(this, &cDelay_RjLgERH8, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Y0y3QXYG, 0.0f);
  numBytes += hTable_init(&hTable_MQncEn8s, 256);
  numBytes += cVar_init_f(&cVar_BLY9gNZ1, 8000.0f);
  numBytes += cBinop_init(&cBinop_XoJcE6ja, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_wPhdn1mk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wXRYKvb7, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_MPhPxoNb, 8000.0f);
  numBytes += cBinop_init(&cBinop_aApsgKT7, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_c0hsA4jL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_of2EJiYD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MOXc2yPK, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_wQ9WXtQn, 300.0f);
  numBytes += cBinop_init(&cBinop_Y2sCBDdV, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_frzP6aH2, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_BmUiEGQH, "del-1011-delayL");
  numBytes += sVarf_init(&sVarf_2ukm8Tfu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3As0lAdK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qbHGUQNF, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_VFNSgroc, "del-1011-delayR");
  numBytes += sVarf_init(&sVarf_Qw2rbQvK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EihGZkyG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nOz2QJMc, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_cV5YYXbx, 8000.0f);
  numBytes += cBinop_init(&cBinop_2CCmo8xj, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_FFW7lOZH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Eop7ktWg, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_o4vFLBRy, 8000.0f);
  numBytes += cBinop_init(&cBinop_bVNAVefb, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_mDuPxTWP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uUQqDj4D, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1rUjxigA, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_DCtQRoZW, 300.0f);
  numBytes += cBinop_init(&cBinop_k7Tq45gR, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_x5YW0xGL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bnLT8lI7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_96uwCUoh, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ESSTJ4dj, 1.0f);
  numBytes += cIf_init(&cIf_86F1oQZS, false);
  numBytes += cIf_init(&cIf_v4ovaVIU, false);
  numBytes += cVar_init_f(&cVar_V3sJWbyO, 0.0f);
  numBytes += cVar_init_f(&cVar_FXF7l7Vs, 0.0f);
  numBytes += cVar_init_f(&cVar_dDXkABrL, 60000.0f);
  numBytes += cVar_init_f(&cVar_C1646YPS, 500.0f);
  numBytes += cSlice_init(&cSlice_ai1HsvhB, 1, -1);
  numBytes += cSlice_init(&cSlice_mC6eMWYx, 1, -1);
  numBytes += cVar_init_f(&cVar_lrW6qtrm, 0.0f);
  numBytes += cIf_init(&cIf_gInX6Yl6, false);
  numBytes += cBinop_init(&cBinop_uT3S5fki, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_bLuOYXkV, 120.0f);
  numBytes += cBinop_init(&cBinop_wmZjj4l9, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_xi0Y7JI4, 0.0f); // __mul
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DLAY::~Heavy_WSTD_DLAY() {
  hTable_free(&hTable_SM7okjh9);
  hTable_free(&hTable_MQncEn8s);
}

HvTable *Heavy_WSTD_DLAY::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x33B09DD4: return &hTable_SM7okjh9; // del-1011-delayL
    case 0xF057CB49: return &hTable_MQncEn8s; // del-1011-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DLAY::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xB6A8F09D: { // Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZeX48aF4_sendMessage);
      break;
    }
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wtyy6mvl_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uCtYGF1N_sendMessage);
      break;
    }
    case 0x4A331B66: { // Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cWLfuj5T_sendMessage);
      break;
    }
    case 0x58E5C2DB: { // Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xZOkFmca_sendMessage);
      break;
    }
    case 0x49107604: { // TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_a1TTv6us_sendMessage);
      break;
    }
    case 0xD640D30E: { // 1011-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yzjg8gxf_sendMessage);
      break;
    }
    case 0xC82F3AD1: { // 1011-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vNK0YYc6_sendMessage);
      break;
    }
    case 0x6E7C47FF: { // 1011-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_stZZx8OF_sendMessage);
      break;
    }
    case 0xD896CBA3: { // 1011-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pR4baIzC_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4Oye9l9G_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_alGdiWJv_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DLAY::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Cross";
        info->hash = 0xB6A8F09D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 1: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Sync";
        info->hash = 0x4A331B66;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "Time";
        info->hash = 0x58E5C2DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 5: {
        info->name = "TimeSync";
        info->hash = 0x49107604;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 6;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DLAY::cVar_qkhe8zn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2OJuijY1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_79Xg04sH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ctuwze8f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_stQnS0zA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MCitLKri_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_DfLAReGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_org9sQ8k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_UYwucRac_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DvJWmnQm, 0, m, &cSlice_DvJWmnQm_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_DvJWmnQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_oordDGnZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_oordDGnZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_sJ9DkADi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oordDGnZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_oordDGnZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_stZZx8OF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_EmeaaieK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3a5l4Tc7, 0, m, &cSlice_3a5l4Tc7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Vw7qrqOQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_3a5l4Tc7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hYXqa6lW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hYXqa6lW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_5XFL79mp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hYXqa6lW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_hYXqa6lW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yzjg8gxf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_lHErfM1b_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mCEEP4EH, 0, m, &cSlice_mCEEP4EH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_UYwucRac_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_mCEEP4EH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_nznwgBnc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_nznwgBnc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_DxFEMHHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nznwgBnc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_nznwgBnc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pR4baIzC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_COPpPBYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_3KVxxddr_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_3KVxxddr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_fWymQL3e_sendMessage);
}

void Heavy_WSTD_DLAY::cUnop_lYmS0jYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_boGvBYR2_sendMessage(_c, 0, m);
  cMsg_EAMzq5J4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cUnop_jZpTtsyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4aTycUcH_sendMessage(_c, 0, m);
  cMsg_bBGs2d0F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_fWymQL3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_5gr7eQOg_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_5gr7eQOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wOIlAz44_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I6TEKT30_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_I6TEKT30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1COVe3Ui_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_wOIlAz44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_7alxWpu5_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_7alxWpu5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5cNWPiPg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_1COVe3Ui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_74ReMIh8_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_74ReMIh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NZfF44Xx_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_5cNWPiPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_lYmS0jYn_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_NZfF44Xx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_jZpTtsyC_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_UOdj5GvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_xKxNuAru_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_xKxNuAru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_Xetu7Vo9_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Xetu7Vo9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_bTr6HH9z_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_bTr6HH9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PM1iieOd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_chrK5mg3_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_chrK5mg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Kb375V0B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_PM1iieOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xpsaHtCw_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_xpsaHtCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SWuhkzck_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_Kb375V0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_R2mn61x7_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_R2mn61x7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_VxZkm4EE_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_VxZkm4EE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Bwaq4qwc_sendMessage(_c, 0, m);
  cMsg_uh4LbEjk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_SWuhkzck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RUqhIIsz_sendMessage(_c, 0, m);
  cMsg_NNiYmaJy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_Vw7qrqOQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_BhrX4HHP, 0, m, &cSlice_BhrX4HHP_sendMessage);
      break;
    }
    default: {
      cSwitchcase_lHErfM1b_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_BhrX4HHP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_m0995AKa_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_m0995AKa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_FoirY4B7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_m0995AKa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_m0995AKa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vNK0YYc6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_Xo0y061v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qXtIRy71_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_qXtIRy71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_7YXs89RJ_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_dheeunJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dheeunJH, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gieYQh9T, 0, m, &cDelay_gieYQh9T_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dheeunJH, 0, m, &cDelay_dheeunJH_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_T440nWX7, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_gieYQh9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gieYQh9T, m);
  cMsg_SoLfQ1G7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_tancZjpj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_BTA9MelI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_oLLHFumS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sUQlComL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_SM7okjh9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0bbysyJk_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dheeunJH, 2, m, &cDelay_dheeunJH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a1jOdPwF_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_sUQlComL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_SM7okjh9, 0, m, &hTable_SM7okjh9_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_7YXs89RJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_oLLHFumS_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_SoLfQ1G7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_SM7okjh9, 0, m, &hTable_SM7okjh9_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_a1jOdPwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dheeunJH, 0, m, &cDelay_dheeunJH_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_0bbysyJk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_gieYQh9T, 2, m, &cDelay_gieYQh9T_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_BTA9MelI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_T440nWX7, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_A2BdpYGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2xVw3bRa_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_2xVw3bRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_X28XDzWr_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_RjLgERH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RjLgERH8, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y0y3QXYG, 0, m, &cDelay_Y0y3QXYG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RjLgERH8, 0, m, &cDelay_RjLgERH8_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_oFijAhFP, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_Y0y3QXYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Y0y3QXYG, m);
  cMsg_NWp4QOih_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_lLZ5Ddib_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Z05GNaTL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_q2xtTOiz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wH5wsA8U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_MQncEn8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MdhnfaIw_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RjLgERH8, 2, m, &cDelay_RjLgERH8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OfE3Lais_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_wH5wsA8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_MQncEn8s, 0, m, &hTable_MQncEn8s_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_X28XDzWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_q2xtTOiz_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_NWp4QOih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_MQncEn8s, 0, m, &hTable_MQncEn8s_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_OfE3Lais_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RjLgERH8, 0, m, &cDelay_RjLgERH8_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_MdhnfaIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y0y3QXYG, 2, m, &cDelay_Y0y3QXYG_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_Z05GNaTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_oFijAhFP, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_BLY9gNZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XoJcE6ja, HV_BINOP_MULTIPLY, 0, m, &cBinop_XoJcE6ja_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_9zyHfaH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QfWKfljC_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_QfWKfljC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fSbzGHu9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_XoJcE6ja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Tw65bE8l_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_XXYROZxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XoJcE6ja, HV_BINOP_MULTIPLY, 1, m, &cBinop_XoJcE6ja_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_fSbzGHu9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_XXYROZxm_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Tw65bE8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_CJHrnpY2_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_CJHrnpY2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_yTSbKu50_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wXRYKvb7, m);
}

void Heavy_WSTD_DLAY::cBinop_yTSbKu50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_wPhdn1mk, m);
}

void Heavy_WSTD_DLAY::cVar_MPhPxoNb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aApsgKT7, HV_BINOP_MULTIPLY, 0, m, &cBinop_aApsgKT7_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_IdINmivL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PhoNtSdf_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_PhoNtSdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2va3cWCm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_aApsgKT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_mSV4MrW3_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_JCF0tWYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aApsgKT7, HV_BINOP_MULTIPLY, 1, m, &cBinop_aApsgKT7_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_2va3cWCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_JCF0tWYr_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_mSV4MrW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_M47xFtft_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_M47xFtft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_n4ajIBB8_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_of2EJiYD, m);
}

void Heavy_WSTD_DLAY::cBinop_n4ajIBB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_c0hsA4jL, m);
}

void Heavy_WSTD_DLAY::cBinop_vnJKheTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_YxYbV3y2_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_YxYbV3y2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9c0Ehw0v_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_V0uFeuTg_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_wQ9WXtQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_EdxYzzkG_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_U3upTSb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SCeLmL13_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_SCeLmL13_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y2sCBDdV, HV_BINOP_DIVIDE, 1, m, &cBinop_Y2sCBDdV_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_9c0Ehw0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ICSDKc2E_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ICSDKc2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_frzP6aH2, m);
}

void Heavy_WSTD_DLAY::cMsg_neUKSGNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_x6TjoUpa_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_x6TjoUpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_vnJKheTf_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_V0uFeuTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_MOXc2yPK, m);
}

void Heavy_WSTD_DLAY::cBinop_EdxYzzkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_vLfPd4Gx_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_vLfPd4Gx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y2sCBDdV, HV_BINOP_DIVIDE, 0, m, &cBinop_Y2sCBDdV_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Y2sCBDdV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_neUKSGNS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_FfoJSJ5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jnX2DTtE_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_jnX2DTtE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_tvFf5jQb_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_BmUiEGQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RXk4qEDG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_o9fBzb1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_lfY7VhfE_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_2ukm8Tfu, m);
}

void Heavy_WSTD_DLAY::cBinop_tvFf5jQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3As0lAdK, m);
}

void Heavy_WSTD_DLAY::cMsg_RXk4qEDG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_o9fBzb1O_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_lfY7VhfE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_qbHGUQNF, m);
}

void Heavy_WSTD_DLAY::cMsg_tO5rhQT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_D7MGdoTg_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_D7MGdoTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_emsQFcMz_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_VFNSgroc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ArLVdLJa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_XyNQsv6X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_IXjikv64_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Qw2rbQvK, m);
}

void Heavy_WSTD_DLAY::cBinop_emsQFcMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_EihGZkyG, m);
}

void Heavy_WSTD_DLAY::cMsg_ArLVdLJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XyNQsv6X_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_IXjikv64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_nOz2QJMc, m);
}

void Heavy_WSTD_DLAY::cVar_cV5YYXbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2CCmo8xj, HV_BINOP_MULTIPLY, 0, m, &cBinop_2CCmo8xj_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_JAdBSHRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ghMQjI4b_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_ghMQjI4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dh8XSBa8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_2CCmo8xj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_DOkQLpd0_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ljv4R81l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2CCmo8xj, HV_BINOP_MULTIPLY, 1, m, &cBinop_2CCmo8xj_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_dh8XSBa8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ljv4R81l_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_DOkQLpd0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_LIauHBau_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_LIauHBau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_uLeBbWxq_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Eop7ktWg, m);
}

void Heavy_WSTD_DLAY::cBinop_uLeBbWxq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FFW7lOZH, m);
}

void Heavy_WSTD_DLAY::cVar_o4vFLBRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bVNAVefb, HV_BINOP_MULTIPLY, 0, m, &cBinop_bVNAVefb_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_xzO1Wkep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vwPHe6ZX_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_vwPHe6ZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0RBqgLbE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_bVNAVefb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_NU8CW3wt_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Rx988d2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bVNAVefb, HV_BINOP_MULTIPLY, 1, m, &cBinop_bVNAVefb_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_0RBqgLbE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Rx988d2S_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_NU8CW3wt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_NDF6dxRE_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_NDF6dxRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_yAWJf6jE_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_uUQqDj4D, m);
}

void Heavy_WSTD_DLAY::cBinop_yAWJf6jE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_mDuPxTWP, m);
}

void Heavy_WSTD_DLAY::cBinop_yjwRbf1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_o0NtYE2e_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_o0NtYE2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_oL41hmxd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_lu8AYNXn_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_DCtQRoZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_zAs2rb3N_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_gM3sWq41_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Ip8Eqfdk_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_Ip8Eqfdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k7Tq45gR, HV_BINOP_DIVIDE, 1, m, &cBinop_k7Tq45gR_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_oL41hmxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_n1NgpLf9_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_n1NgpLf9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_x5YW0xGL, m);
}

void Heavy_WSTD_DLAY::cMsg_q5pgJ36N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HeefuWq0_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_HeefuWq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_yjwRbf1Q_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_lu8AYNXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_1rUjxigA, m);
}

void Heavy_WSTD_DLAY::cBinop_zAs2rb3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_Z78ObAUJ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Z78ObAUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k7Tq45gR, HV_BINOP_DIVIDE, 0, m, &cBinop_k7Tq45gR_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_k7Tq45gR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q5pgJ36N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_boGvBYR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lkuoKWSv, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_4aTycUcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9srhMAgI, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_bBGs2d0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_stIXvvmX, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_EAMzq5J4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vCojiN78, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_NNiYmaJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yf4r5mYK, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_Bwaq4qwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jROL20tm, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_RUqhIIsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Tedpgzmd, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_uh4LbEjk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EaRaYPbQ, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_IYNEvbse_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mLOdv0pY, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_3XxYiru0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CC2ESNlM, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_0OMkTv0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iFit4FEA, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_cOI0yOHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cPOTQ0zT, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_ESSTJ4dj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lDhGMA6B_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gPpEMFeY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_4RYiqSfz_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_lDhGMA6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ESSTJ4dj, 1, m, &cVar_ESSTJ4dj_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_86F1oQZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_79Xg04sH, 0, m, &cVar_79Xg04sH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cIf_v4ovaVIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_79Xg04sH, 0, m, &cVar_79Xg04sH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_V3sJWbyO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_v4ovaVIU, 0, m, &cIf_v4ovaVIU_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_FXF7l7Vs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_86F1oQZS, 0, m, &cIf_86F1oQZS_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_dDXkABrL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wmZjj4l9, HV_BINOP_DIVIDE, 0, m, &cBinop_wmZjj4l9_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_C1646YPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xi0Y7JI4, HV_BINOP_MULTIPLY, 1, m, &cBinop_xi0Y7JI4_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_CnX9868O_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ai1HsvhB, 0, m, &cSlice_ai1HsvhB_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mC6eMWYx, 0, m, &cSlice_mC6eMWYx_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dDzaLfpf_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UmUoKvOd_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_ai1HsvhB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_lrW6qtrm, 0, m, &cVar_lrW6qtrm_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_lrW6qtrm, 0, m, &cVar_lrW6qtrm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cSlice_mC6eMWYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_uT3S5fki, HV_BINOP_NEQ, 1, m, &cBinop_uT3S5fki_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_lrW6qtrm, 1, m, &cVar_lrW6qtrm_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_uT3S5fki, HV_BINOP_NEQ, 1, m, &cBinop_uT3S5fki_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_lrW6qtrm, 1, m, &cVar_lrW6qtrm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_lrW6qtrm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_Bg6nrUwK_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_gInX6Yl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EBIBilab_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_okKJiXaI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cCast_okKJiXaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lrW6qtrm, 0, m, &cVar_lrW6qtrm_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_EBIBilab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uT3S5fki, HV_BINOP_NEQ, 1, m, &cBinop_uT3S5fki_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_uT3S5fki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gInX6Yl6, 1, m, &cIf_gInX6Yl6_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_UmUoKvOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gInX6Yl6, 0, m, &cIf_gInX6Yl6_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_dDzaLfpf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uT3S5fki, HV_BINOP_NEQ, 0, m, &cBinop_uT3S5fki_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_bLuOYXkV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DNWJHWjG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yyIyIK3P_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_dQ176B9I_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jYZImzZc_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7iVTN7Mu_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1PhvAy4X_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BH8NHHKB_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o7zWQsws_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mJQomEgj_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oxKKNPlr_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UlEzcUPn_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h6juPtks_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zWsyPMW3_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CYzUUuJy_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s0bGsX4B_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GA3cwY4h_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cCast_jYZImzZc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fxf4bVYY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_7iVTN7Mu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NJW4NPMq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_1PhvAy4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RnsDG2Q9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_BH8NHHKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NvX14gbG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_o7zWQsws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1CM8HBMx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_mJQomEgj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2YeclZjY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_oxKKNPlr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BuHBIrlL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_UlEzcUPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HpP25skg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_h6juPtks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sbdzcyZw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_zWsyPMW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mm0alp6D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_CYzUUuJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wA1sHUjl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_s0bGsX4B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V1EQ9K2s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_GA3cwY4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jE1flYGi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_wmZjj4l9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xi0Y7JI4, HV_BINOP_MULTIPLY, 0, m, &cBinop_xi0Y7JI4_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_xi0Y7JI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_CnX9868O_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cCast_DNWJHWjG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wmZjj4l9, HV_BINOP_DIVIDE, 1, m, &cBinop_wmZjj4l9_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_yyIyIK3P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dDXkABrL, 0, m, &cVar_dDXkABrL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_C1646YPS, 0, m, &cVar_C1646YPS_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_aIlaI6pN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_C1646YPS, 0, m, &cVar_C1646YPS_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_2oO9oDvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dDXkABrL, 0, m, &cVar_dDXkABrL_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_Fxf4bVYY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aIlaI6pN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2oO9oDvl_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_NJW4NPMq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aIlaI6pN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2oO9oDvl_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_RnsDG2Q9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aIlaI6pN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2oO9oDvl_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_NvX14gbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aIlaI6pN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2oO9oDvl_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_1CM8HBMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aIlaI6pN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2oO9oDvl_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_2YeclZjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aIlaI6pN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2oO9oDvl_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_BuHBIrlL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aIlaI6pN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2oO9oDvl_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_HpP25skg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aIlaI6pN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2oO9oDvl_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_sbdzcyZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aIlaI6pN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2oO9oDvl_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_mm0alp6D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aIlaI6pN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2oO9oDvl_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_wA1sHUjl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aIlaI6pN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2oO9oDvl_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_V1EQ9K2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aIlaI6pN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2oO9oDvl_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_jE1flYGi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aIlaI6pN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2oO9oDvl_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_org9sQ8k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_EmeaaieK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_2OJuijY1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_EmeaaieK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_cxiXhmG5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DfLAReGG, 0, m, &cVar_DfLAReGG_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_URk51W0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qkhe8zn6, 0, m, &cVar_qkhe8zn6_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_28zmDUVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_stQnS0zA, 0, m, &cVar_stQnS0zA_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_Ctuwze8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_EmeaaieK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_MCitLKri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_EmeaaieK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_Bg6nrUwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FXF7l7Vs, 0, m, &cVar_FXF7l7Vs_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_4RYiqSfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W3oh90tz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wACaMcGq_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_gPpEMFeY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aTD24hyQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XWfyn9Zz_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_XWfyn9Zz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_V3sJWbyO, 0, m, &cVar_V3sJWbyO_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_aTD24hyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_v4ovaVIU, 1, m, &cIf_v4ovaVIU_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_wACaMcGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FXF7l7Vs, 0, m, &cVar_FXF7l7Vs_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_W3oh90tz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_86F1oQZS, 1, m, &cIf_86F1oQZS_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_uCtYGF1N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_cxiXhmG5_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_wtyy6mvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_URk51W0g_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_ZeX48aF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_28zmDUVs_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_xZOkFmca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_V3sJWbyO, 0, m, &cVar_V3sJWbyO_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_pR4baIzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IYNEvbse_sendMessage(_c, 0, m);
  cMsg_3XxYiru0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_vNK0YYc6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0OMkTv0R_sendMessage(_c, 0, m);
  cMsg_cOI0yOHs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_stZZx8OF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_COPpPBYz_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_alGdiWJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sJ9DkADi, 0, m, &cVar_sJ9DkADi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5XFL79mp, 0, m, &cVar_5XFL79mp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DxFEMHHU, 0, m, &cVar_DxFEMHHU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FoirY4B7, 0, m, &cVar_FoirY4B7_sendMessage);
  cMsg_Xo0y061v_sendMessage(_c, 0, m);
  cMsg_A2BdpYGu_sendMessage(_c, 0, m);
  cMsg_9zyHfaH4_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_BLY9gNZ1, 0, m, &cVar_BLY9gNZ1_sendMessage);
  cMsg_IdINmivL_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_MPhPxoNb, 0, m, &cVar_MPhPxoNb_sendMessage);
  cMsg_U3upTSb0_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_wQ9WXtQn, 0, m, &cVar_wQ9WXtQn_sendMessage);
  cMsg_JAdBSHRN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_cV5YYXbx, 0, m, &cVar_cV5YYXbx_sendMessage);
  cMsg_xzO1Wkep_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_o4vFLBRy, 0, m, &cVar_o4vFLBRy_sendMessage);
  cMsg_gM3sWq41_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_DCtQRoZW, 0, m, &cVar_DCtQRoZW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BmUiEGQH, 0, m, &cVar_BmUiEGQH_sendMessage);
  cMsg_FfoJSJ5C_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_VFNSgroc, 0, m, &cVar_VFNSgroc_sendMessage);
  cMsg_tO5rhQT6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_yzjg8gxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_UOdj5GvY_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_cWLfuj5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ESSTJ4dj, 0, m, &cVar_ESSTJ4dj_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_4Oye9l9G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bLuOYXkV, 0, m, &cVar_bLuOYXkV_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_a1TTv6us_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dQ176B9I_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DLAY::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_9srhMAgI, VOf(Bf0));
    __hv_line_f(&sLine_mLOdv0pY, VOf(Bf1));
    __hv_tabhead_f(&sTabhead_jpXBdg5E, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf3), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_3As0lAdK, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_qbHGUQNF, VOf(Bf1));
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf3));
    __hv_varread_f(&sVarf_2ukm8Tfu, VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_lt_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_cast_fi(VIf(Bf4), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_L3Gk7I70, VIi(Bi1), VOf(Bf4));
    __hv_tabread_if(&sTabread_Hut3FTCE, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf4), VIf(Bf1), VOf(Bf4));
    __hv_sub_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_lkuoKWSv, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_stIXvvmX, VOf(Bf0));
    __hv_line_f(&sLine_CC2ESNlM, VOf(Bf4));
    __hv_tabhead_f(&sTabhead_rhGB4tdQ, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf5), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_EihGZkyG, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_nOz2QJMc, VOf(Bf4));
    __hv_min_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf5));
    __hv_varread_f(&sVarf_Qw2rbQvK, VOf(Bf4));
    __hv_zero_f(VOf(Bf6));
    __hv_lt_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_and_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_cast_fi(VIf(Bf6), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_1ooqB4uT, VIi(Bi1), VOf(Bf6));
    __hv_tabread_if(&sTabread_n5BCh1O1, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf6));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf6), VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_vCojiN78, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(I1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_bnLT8lI7, VOf(Bf0));
    __hv_add_f(VIf(I0), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_T440nWX7, VIf(Bf0));
    __hv_varread_f(&sVarf_96uwCUoh, VOf(Bf0));
    __hv_add_f(VIf(I1), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_oFijAhFP, VIf(Bf0));
    __hv_varread_f(&sVarf_wXRYKvb7, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_wPhdn1mk, VOf(Bf1));
    __hv_rpole_f(&sRPole_kui4inrM, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_of2EJiYD, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_c0hsA4jL, VOf(Bf1));
    __hv_rpole_f(&sRPole_AcTR6MJm, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_MOXc2yPK, VOf(Bf0));
    __hv_rpole_f(&sRPole_foSd1y6U, VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_6RTjs918, VIf(Bf0), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_frzP6aH2, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_iFit4FEA, VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_jROL20tm, VOf(Bf0));
    __hv_varread_f(&sVarf_Eop7ktWg, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_FFW7lOZH, VOf(Bf4));
    __hv_rpole_f(&sRPole_FnEjEyXf, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_uUQqDj4D, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_mDuPxTWP, VOf(Bf4));
    __hv_rpole_f(&sRPole_qZ5Exg3F, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_1rUjxigA, VOf(Bf6));
    __hv_rpole_f(&sRPole_rqpbwQeI, VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_OOqeQ7E0, VIf(Bf6), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_x5YW0xGL, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_cPOTQ0zT, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_yf4r5mYK, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_bnLT8lI7, VIf(Bf6));
    __hv_line_f(&sLine_EaRaYPbQ, VOf(Bf6));
    __hv_line_f(&sLine_Tedpgzmd, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf4), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_96uwCUoh, VIf(Bf0));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DLAY::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DLAY::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
