/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_DLAY_HPP_
#define _HEAVY_CONTEXT_WSTD_DLAY_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlUnop.h"
#include "HvControlIf.h"
#include "HvControlCast.h"
#include "HvControlSystem.h"
#include "HvControlSlice.h"
#include "HvControlDelay.h"
#include "HvSignalVar.h"
#include "HvSignalDel1.h"
#include "HvTable.h"
#include "HvSignalTabwrite.h"
#include "HvSignalTabread.h"
#include "HvControlVar.h"
#include "HvMath.h"
#include "HvControlBinop.h"
#include "HvSignalRPole.h"
#include "HvSignalLine.h"

class Heavy_WSTD_DLAY : public HeavyContext {

 public:
  Heavy_WSTD_DLAY(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_DLAY();

  const char *getName() override { return "WSTD_DLAY"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CROSS = 0xB6A8F09D, // Cross
        FEEDBACK = 0x57157946, // Feedback
        MIX = 0x97D46AC6, // Mix
        SYNC = 0x4A331B66, // Sync
        TIME = 0x58E5C2DB, // Time
        TIMESYNC = 0x49107604, // TimeSync
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_qkhe8zn6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_79Xg04sH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_stQnS0zA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DfLAReGG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_UYwucRac_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_DvJWmnQm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sJ9DkADi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_oordDGnZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_EmeaaieK_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_3a5l4Tc7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5XFL79mp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hYXqa6lW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_lHErfM1b_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_mCEEP4EH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DxFEMHHU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_nznwgBnc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_COPpPBYz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3KVxxddr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_lYmS0jYn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jZpTtsyC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fWymQL3e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5gr7eQOg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I6TEKT30_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wOIlAz44_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7alxWpu5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1COVe3Ui_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_74ReMIh8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5cNWPiPg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NZfF44Xx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UOdj5GvY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xKxNuAru_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Xetu7Vo9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bTr6HH9z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_chrK5mg3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PM1iieOd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xpsaHtCw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Kb375V0B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R2mn61x7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VxZkm4EE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SWuhkzck_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Vw7qrqOQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_BhrX4HHP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FoirY4B7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_m0995AKa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Xo0y061v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_qXtIRy71_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_dheeunJH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_gieYQh9T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_tancZjpj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_oLLHFumS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_SM7okjh9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sUQlComL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7YXs89RJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SoLfQ1G7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a1jOdPwF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0bbysyJk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BTA9MelI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A2BdpYGu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_2xVw3bRa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_RjLgERH8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Y0y3QXYG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_lLZ5Ddib_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_q2xtTOiz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_MQncEn8s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wH5wsA8U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X28XDzWr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NWp4QOih_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OfE3Lais_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MdhnfaIw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Z05GNaTL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BLY9gNZ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9zyHfaH4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_QfWKfljC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XoJcE6ja_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XXYROZxm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fSbzGHu9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Tw65bE8l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CJHrnpY2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yTSbKu50_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MPhPxoNb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IdINmivL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_PhoNtSdf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aApsgKT7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JCF0tWYr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2va3cWCm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mSV4MrW3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M47xFtft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n4ajIBB8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vnJKheTf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YxYbV3y2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wQ9WXtQn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U3upTSb0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_SCeLmL13_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9c0Ehw0v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ICSDKc2E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_neUKSGNS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x6TjoUpa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V0uFeuTg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EdxYzzkG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vLfPd4Gx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y2sCBDdV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FfoJSJ5C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_jnX2DTtE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BmUiEGQH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_o9fBzb1O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tvFf5jQb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RXk4qEDG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lfY7VhfE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tO5rhQT6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_D7MGdoTg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VFNSgroc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_XyNQsv6X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_emsQFcMz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ArLVdLJa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IXjikv64_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cV5YYXbx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JAdBSHRN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ghMQjI4b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2CCmo8xj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ljv4R81l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dh8XSBa8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DOkQLpd0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LIauHBau_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uLeBbWxq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_o4vFLBRy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xzO1Wkep_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_vwPHe6ZX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bVNAVefb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rx988d2S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0RBqgLbE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NU8CW3wt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NDF6dxRE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yAWJf6jE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yjwRbf1Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o0NtYE2e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DCtQRoZW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gM3sWq41_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Ip8Eqfdk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oL41hmxd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n1NgpLf9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q5pgJ36N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HeefuWq0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lu8AYNXn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zAs2rb3N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z78ObAUJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k7Tq45gR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_boGvBYR2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4aTycUcH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bBGs2d0F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EAMzq5J4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NNiYmaJy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Bwaq4qwc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RUqhIIsz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uh4LbEjk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IYNEvbse_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3XxYiru0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0OMkTv0R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cOI0yOHs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ESSTJ4dj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lDhGMA6B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_86F1oQZS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_v4ovaVIU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_V3sJWbyO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FXF7l7Vs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dDXkABrL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_C1646YPS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_CnX9868O_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ai1HsvhB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_mC6eMWYx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lrW6qtrm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gInX6Yl6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_okKJiXaI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EBIBilab_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uT3S5fki_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UmUoKvOd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dDzaLfpf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bLuOYXkV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dQ176B9I_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_jYZImzZc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7iVTN7Mu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1PhvAy4X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BH8NHHKB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o7zWQsws_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mJQomEgj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oxKKNPlr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UlEzcUPn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h6juPtks_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zWsyPMW3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CYzUUuJy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s0bGsX4B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GA3cwY4h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wmZjj4l9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xi0Y7JI4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DNWJHWjG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yyIyIK3P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aIlaI6pN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2oO9oDvl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Fxf4bVYY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NJW4NPMq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RnsDG2Q9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NvX14gbG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1CM8HBMx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2YeclZjY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BuHBIrlL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HpP25skg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sbdzcyZw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mm0alp6D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wA1sHUjl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V1EQ9K2s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jE1flYGi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_org9sQ8k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2OJuijY1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cxiXhmG5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_URk51W0g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_28zmDUVs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ctuwze8f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MCitLKri_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Bg6nrUwK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4RYiqSfz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gPpEMFeY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XWfyn9Zz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aTD24hyQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wACaMcGq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W3oh90tz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uCtYGF1N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wtyy6mvl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZeX48aF4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xZOkFmca_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pR4baIzC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vNK0YYc6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_stZZx8OF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_alGdiWJv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yzjg8gxf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cWLfuj5T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4Oye9l9G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_a1TTv6us_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_9srhMAgI;
  SignalLine sLine_mLOdv0pY;
  SignalTabhead sTabhead_jpXBdg5E;
  SignalTabread sTabread_L3Gk7I70;
  SignalTabread sTabread_Hut3FTCE;
  SignalLine sLine_lkuoKWSv;
  SignalLine sLine_stIXvvmX;
  SignalLine sLine_CC2ESNlM;
  SignalTabhead sTabhead_rhGB4tdQ;
  SignalTabread sTabread_1ooqB4uT;
  SignalTabread sTabread_n5BCh1O1;
  SignalLine sLine_vCojiN78;
  SignalTabwrite sTabwrite_T440nWX7;
  SignalTabwrite sTabwrite_oFijAhFP;
  SignalRPole sRPole_kui4inrM;
  SignalRPole sRPole_AcTR6MJm;
  SignalRPole sRPole_foSd1y6U;
  SignalDel1 sDel1_6RTjs918;
  SignalLine sLine_iFit4FEA;
  SignalLine sLine_jROL20tm;
  SignalRPole sRPole_FnEjEyXf;
  SignalRPole sRPole_qZ5Exg3F;
  SignalRPole sRPole_rqpbwQeI;
  SignalDel1 sDel1_OOqeQ7E0;
  SignalLine sLine_cPOTQ0zT;
  SignalLine sLine_yf4r5mYK;
  SignalLine sLine_EaRaYPbQ;
  SignalLine sLine_Tedpgzmd;
  ControlVar cVar_qkhe8zn6;
  ControlVar cVar_79Xg04sH;
  ControlVar cVar_stQnS0zA;
  ControlVar cVar_DfLAReGG;
  ControlSlice cSlice_DvJWmnQm;
  ControlVar cVar_sJ9DkADi;
  ControlSlice cSlice_3a5l4Tc7;
  ControlVar cVar_5XFL79mp;
  ControlSlice cSlice_mCEEP4EH;
  ControlVar cVar_DxFEMHHU;
  ControlBinop cBinop_COPpPBYz;
  ControlBinop cBinop_3KVxxddr;
  ControlBinop cBinop_fWymQL3e;
  ControlBinop cBinop_5gr7eQOg;
  ControlBinop cBinop_7alxWpu5;
  ControlBinop cBinop_74ReMIh8;
  ControlBinop cBinop_5cNWPiPg;
  ControlBinop cBinop_NZfF44Xx;
  ControlBinop cBinop_UOdj5GvY;
  ControlBinop cBinop_xKxNuAru;
  ControlBinop cBinop_Xetu7Vo9;
  ControlBinop cBinop_bTr6HH9z;
  ControlBinop cBinop_xpsaHtCw;
  ControlBinop cBinop_R2mn61x7;
  ControlBinop cBinop_VxZkm4EE;
  ControlBinop cBinop_SWuhkzck;
  ControlSlice cSlice_BhrX4HHP;
  ControlVar cVar_FoirY4B7;
  ControlDelay cDelay_dheeunJH;
  ControlDelay cDelay_gieYQh9T;
  ControlBinop cBinop_oLLHFumS;
  HvTable hTable_SM7okjh9;
  ControlBinop cBinop_7YXs89RJ;
  ControlDelay cDelay_RjLgERH8;
  ControlDelay cDelay_Y0y3QXYG;
  ControlBinop cBinop_q2xtTOiz;
  HvTable hTable_MQncEn8s;
  ControlBinop cBinop_X28XDzWr;
  ControlVar cVar_BLY9gNZ1;
  ControlBinop cBinop_XoJcE6ja;
  ControlBinop cBinop_XXYROZxm;
  SignalVarf sVarf_wPhdn1mk;
  ControlBinop cBinop_Tw65bE8l;
  ControlBinop cBinop_CJHrnpY2;
  ControlBinop cBinop_yTSbKu50;
  SignalVarf sVarf_wXRYKvb7;
  ControlVar cVar_MPhPxoNb;
  ControlBinop cBinop_aApsgKT7;
  ControlBinop cBinop_JCF0tWYr;
  SignalVarf sVarf_c0hsA4jL;
  ControlBinop cBinop_mSV4MrW3;
  ControlBinop cBinop_M47xFtft;
  ControlBinop cBinop_n4ajIBB8;
  SignalVarf sVarf_of2EJiYD;
  ControlBinop cBinop_vnJKheTf;
  ControlBinop cBinop_YxYbV3y2;
  SignalVarf sVarf_MOXc2yPK;
  ControlVar cVar_wQ9WXtQn;
  ControlBinop cBinop_9c0Ehw0v;
  ControlBinop cBinop_ICSDKc2E;
  ControlBinop cBinop_x6TjoUpa;
  ControlBinop cBinop_V0uFeuTg;
  ControlBinop cBinop_EdxYzzkG;
  ControlBinop cBinop_vLfPd4Gx;
  ControlBinop cBinop_Y2sCBDdV;
  SignalVarf sVarf_frzP6aH2;
  ControlVar cVar_BmUiEGQH;
  ControlBinop cBinop_tvFf5jQb;
  ControlBinop cBinop_lfY7VhfE;
  SignalVarf sVarf_2ukm8Tfu;
  SignalVarf sVarf_3As0lAdK;
  SignalVarf sVarf_qbHGUQNF;
  ControlVar cVar_VFNSgroc;
  ControlBinop cBinop_emsQFcMz;
  ControlBinop cBinop_IXjikv64;
  SignalVarf sVarf_Qw2rbQvK;
  SignalVarf sVarf_EihGZkyG;
  SignalVarf sVarf_nOz2QJMc;
  ControlVar cVar_cV5YYXbx;
  ControlBinop cBinop_2CCmo8xj;
  ControlBinop cBinop_ljv4R81l;
  SignalVarf sVarf_FFW7lOZH;
  ControlBinop cBinop_DOkQLpd0;
  ControlBinop cBinop_LIauHBau;
  ControlBinop cBinop_uLeBbWxq;
  SignalVarf sVarf_Eop7ktWg;
  ControlVar cVar_o4vFLBRy;
  ControlBinop cBinop_bVNAVefb;
  ControlBinop cBinop_Rx988d2S;
  SignalVarf sVarf_mDuPxTWP;
  ControlBinop cBinop_NU8CW3wt;
  ControlBinop cBinop_NDF6dxRE;
  ControlBinop cBinop_yAWJf6jE;
  SignalVarf sVarf_uUQqDj4D;
  ControlBinop cBinop_yjwRbf1Q;
  ControlBinop cBinop_o0NtYE2e;
  SignalVarf sVarf_1rUjxigA;
  ControlVar cVar_DCtQRoZW;
  ControlBinop cBinop_oL41hmxd;
  ControlBinop cBinop_n1NgpLf9;
  ControlBinop cBinop_HeefuWq0;
  ControlBinop cBinop_lu8AYNXn;
  ControlBinop cBinop_zAs2rb3N;
  ControlBinop cBinop_Z78ObAUJ;
  ControlBinop cBinop_k7Tq45gR;
  SignalVarf sVarf_x5YW0xGL;
  SignalVarf sVarf_bnLT8lI7;
  SignalVarf sVarf_96uwCUoh;
  ControlVar cVar_ESSTJ4dj;
  ControlBinop cBinop_lDhGMA6B;
  ControlIf cIf_86F1oQZS;
  ControlIf cIf_v4ovaVIU;
  ControlVar cVar_V3sJWbyO;
  ControlVar cVar_FXF7l7Vs;
  ControlVar cVar_dDXkABrL;
  ControlVar cVar_C1646YPS;
  ControlSlice cSlice_ai1HsvhB;
  ControlSlice cSlice_mC6eMWYx;
  ControlVar cVar_lrW6qtrm;
  ControlIf cIf_gInX6Yl6;
  ControlBinop cBinop_uT3S5fki;
  ControlVar cVar_bLuOYXkV;
  ControlBinop cBinop_wmZjj4l9;
  ControlBinop cBinop_xi0Y7JI4;
  ControlBinop cBinop_cxiXhmG5;
  ControlBinop cBinop_URk51W0g;
  ControlBinop cBinop_28zmDUVs;
  ControlBinop cBinop_Bg6nrUwK;
  ControlBinop cBinop_4RYiqSfz;
  ControlBinop cBinop_gPpEMFeY;
};

#endif // _HEAVY_CONTEXT_WSTD_DLAY_HPP_
